==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtbucketHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "ϓoPbg"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "oPbgsPʂƂȂ鍀ږXg"

/*-f*/
#define FLDT "鍀ږXg"
#define FLDC "Ŏw肵ڂ̒lɊÂĕȂ"
#define FLDF NULL

/*-n*/
#define NUMT ""
#define NUMC "oPbg̐w肷"

/*-F*/
#define FMTT "o͌`"
#define FMTC "oPbg̖Oo͌`"
#define FMTS "oPbgԍ,l͈,oPbgԍ+l͈"

/*-c*/
#define TYPT "oPbg^Cv"
#define TYPC "oPbg̐l͈͂̌ߕw肷"
#define TYPS "ϓoPbg,l͈͋ϓoPbg"

/*-r*/
#define REVT "t"
#define REVC "oPbgԍo͂ƂAl̑傫ɃoPbgԍ1ӂĂ"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "L[ږXgŎw肵ڂPʂɂāA-f̂Ŏw肵lڂAł邾ϓɂȂ悤ȃoPbgɕB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbucket -f z, -n 5 -i dat.xt -o rsl.xt\n\
xtbucket -f z, -n 5 -F 1 -i dat.xt -o rsl.xt\n\
xtbucket -k ڋq -f z, -n 5 -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtagg,xtstatistics,xtshare"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/ja-sjis/xtbucketHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "ϓoPbg"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "oPbgsPʂƂȂ鍀ږXg"

/*-f*/
#define FLDT "鍀ږXg"
#define FLDC "Ŏw肵ڂ̒lɊÂĕȂ"
#define FLDF NULL

/*-n*/
#define NUMT ""
#define NUMC "oPbg̐w肷"

/*-F*/
#define FMTT "o͌`"
#define FMTC "oPbg̖Oo͌`"
#define FMTS "oPbgԍ,l͈,oPbgԍ+l͈"

/*-c*/
#define TYPT "oPbg^Cv"
#define TYPC "oPbg̐l͈͂̌ߕw肷"
#define TYPS "ϓoPbg,l͈͋ϓoPbg"

/*-r*/
#define REVT "t"
#define REVC "oPbgԍo͂ƂAl̑傫ɃoPbgԍ1ӂĂ"

/*-O*/
#define RNGT "oPbg͈͏o̓t@C"
#define RNGC "e(-f)̊eoPbg̐l͈͂o͂t@C"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "L[ږXgŎw肵ڂPʂɂāA-f̂Ŏw肵lڂAł邾ϓɂȂ悤ȃoPbgɕB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbucket -f z:zoPbg,:ʃoPbg -n 5 -i dat.xt -o rsl.xt\n\
xtbucket -f z:zoPbg,:ʃoPbg -n 5 -F 1 -i dat.xt -o rsl.xt\n\
xtbucket -k ڋq -f z:zoPbg,:ʃoPbg -n 5 -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtagg,xtstatistics,xtshare"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
